@@ -334,53 +334,53 @@ class IWAVE(BaseEstimator):
         ... )
         Initializing model parameters
         Initialization ended in  0.0  seconds
-        >>> model.fit(data, iw_samples = 5)
+        >>> model.fit(data, iw_samples = 10)
         Fitting started
-        Epoch =     846 Iter. =  27101 Cur. loss =   11.15   Intervals no change = 100
-        Fitting ended in  95.14  seconds
+        Epoch =       78 Iter. =    19701 Cur. loss =   11.09   Intervals no change =  100
+        Fitting ended in  74.52  seconds
         >>> model.loadings
-        tensor([[1.4004, 0.0000, 0.0000, 0.0000],
-                [1.3816, 0.0000, 0.0000, 0.0000],
-                [0.5557, 0.0000, 0.0000, 0.0000],
-                [0.0000, 0.5833, 0.0000, 0.0000],
-                [0.0000, 1.0996, 0.0000, 0.0000],
-                [0.0000, 1.7175, 0.0000, 0.0000],
-                [0.0000, 0.0000, 0.7294, 0.0000],
-                [0.0000, 0.0000, 0.5775, 0.0000],
-                [0.0000, 0.0000, 1.1082, 0.0000],
-                [0.0000, 0.0000, 0.0000, 1.6827],
-                [0.0000, 0.0000, 0.0000, 0.7021],
-                [0.0000, 0.0000, 0.0000, 0.6706]])
+        tensor([[0.8456, 0.0000, 0.0000, 0.0000],
+                [0.6506, 0.0000, 0.0000, 0.0000],
+                [0.6670, 0.0000, 0.0000, 0.0000],
+                [0.0000, 0.6398, 0.0000, 0.0000],
+                [0.0000, 1.1146, 0.0000, 0.0000],
+                [0.0000, 1.2914, 0.0000, 0.0000],
+                [0.0000, 0.0000, 0.8141, 0.0000],
+                [0.0000, 0.0000, 1.3549, 0.0000],
+                [0.0000, 0.0000, 1.4892, 0.0000],
+                [0.0000, 0.0000, 0.0000, 1.0622],
+                [0.0000, 0.0000, 0.0000, 1.3446],
+                [0.0000, 0.0000, 0.0000, 1.1498]])
         >>> model.intercepts
-        tensor([[-1.2907,  1.4794],
-                [-0.6921,  1.2275],
-                [-0.4097,  0.3086],
-                [-2.0435,  1.3194],
-                [-2.8560,  1.0286],
-                [-0.2557,  1.9871],
-                [-1.6538,  0.6874],
-                [-0.4569,  0.8666],
-                [-1.2310,  1.7704],
-                [-1.1810,  0.2015],
-                [-0.6825,  2.5192],
-                [-2.8031,  2.7023]])
+        tensor([[-0.1202,  2.4450],
+                [-0.9971,  1.8080],
+                [-1.1140,  2.0810],
+                [-1.7245,  0.0466],
+                [-2.2886,  2.5354],
+                [-1.5748,  0.2589],
+                [-1.2884,  2.8013],
+                [-2.8611,  0.4436],
+                [-2.1389,  1.6103],
+                [-1.8367,  1.3795],
+                [-2.7932,  2.1621],
+                [-0.1536,  2.4888]])
         >>> model.cov
-        tensor([[1.0000, 0.1679, 0.1489, 0.2227],
-                [0.1679, 1.0000, 0.1406, 0.2248],
-                [0.1489, 0.1406, 1.0000, 0.1452],
-                [0.2227, 0.2248, 0.1452, 1.0000]])
+        tensor([[ 1.0000, -0.0819,  0.2108,  0.2989],
+                [-0.0819,  1.0000, -0.1252, -0.2714],
+                [ 0.2108, -0.1252,  1.0000,  0.1322],
+                [ 0.2989, -0.2714,  0.1322,  1.0000]])
         >>>  model.log_likelihood(data)
         Computing approx. LL
-        Approx. LL computed in 3.81 seconds
-        -11352.973602294922
+        Approx. LL computed in 29.01 seconds
+        -86194.04898071289
         >>> model.scores(data)
-        tensor([[-0.6504, -0.1423,  0.7591, -1.7465],
-                [ 0.7054, -1.0571, -0.0198, -2.4142],
-                [ 0.4145, -0.7144,  1.2089,  0.6287],
+        tensor([[-0.9682,  2.0518, -1.3156, -0.8087],
+                [-1.0009,  0.4465,  0.3619,  0.9397],
+                [-0.2995, -0.2615,  1.5835,  0.5501],
                 ...,
-                [-0.3914,  1.4080,  0.1451,  0.2159],
-                [ 1.7497,  0.0664, -1.8161, -0.8235],
-                [ 0.6082, -0.2060, -0.1357,  0.7942]])
+                [-0.1856, -2.0889, -0.0113, -0.0937],
+                [ 0.4250, -0.4520, -0.8553, -1.5701],
+                [-1.9710, -1.0868,  0.6147,  1.4418]])
     """
     
     def __init__(self,
@@ -502,7 +502,7 @@ class IWAVE(BaseEstimator):
         loader =  torch.utils.data.DataLoader(
                     tensor_dataset(data = data, mask = missing_mask,
                                    covariates = covariates),
-                    batch_size = 32, shuffle = True,
+                    batch_size = 32, shuffle = False,
                     pin_memory = self.device == "cuda",
                   )
         
@@ -570,7 +570,7 @@ class IWAVE(BaseEstimator):
         loader = torch.utils.data.DataLoader(
                     tensor_dataset(data = data, mask = missing_mask,
                                    covariates = covariates),
-                    batch_size = 32, shuffle = True,
+                    batch_size = 32, shuffle = False,
                     pin_memory = self.device == "cuda",
                   )
         
@@ -643,7 +643,7 @@ class IWAVE(BaseEstimator):
     @property
     def probs(self):
         try:
-            logits_to_probs(self.model.decoder.logits.data.cpu(), is_binary = True)
+            return logits_to_probs(self.model.decoder.logits.data.cpu(), is_binary = True)
         except AttributeError:
             return None
         except TypeError:
